@@ -8,5 +8,5 @@
 pub unsafe fn exit(status: i32) -> ! {
     let status = status as usize;
     let _ret = syscall1(SYS_EXIT, status);
-    unreachable!();
+    core::hint::unreachable_unchecked();
 }
